from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``ru_RU`` locale."""

    word_list = (
        'войти', 'монета', 'вскинуть', 'желание', 'экзамен', 'налоговый',
        'вытаскивать', 'приятель', 'вздрагивать', 'куча', 'порт', 'точно',
        'заплакать', 'изба', 'правление', 'художественный', 'мучительно',
        'изображать', 'фонарик', 'миф', 'грустный', 'опасность', 'мера',
        'пастух', 'факультет', 'мелькнуть', 'полевой', 'другой', 'выраженный',
        'забирать', 'рот', 'народ', 'соответствие', 'тута', 'коммунизм',
        'решение', 'плод', 'собеседник', 'возмутиться', 'достоинство',
        'господь', 'болото', 'инфекция', 'голубчик', 'сынок', 'пространство',
        'прощение', 'прежде', 'хотеть', 'ленинград', 'даль', 'развитый',
        'близко', 'более', 'спорт', 'эпоха', 'ответить', 'освободить', 'совет',
        'проход', 'палец', 'вчера', 'приличный', 'ярко', 'белье', 'кузнец',
        'неожиданно', 'вперед', 'зато', 'кольцо', 'передо', 'мгновение',
        'плавно', 'табак', 'число', 'изучить', 'тяжелый', 'рассуждение',
        'салон', 'идея', 'что', 'светило', 'порода', 'сомнительный', 'бок',
        'очко', 'неудобно', 'советовать', 'отдел', 'помолчать', 'поздравлять',
        'пробовать', 'дошлый', 'смеяться', 'упорно', 'вздрогнуть', 'затянуться',
        'танцевать', 'песенка', 'выбирать', 'правильный', 'намерение', 'издали',
        'запустить', 'наслаждение', 'крыса', 'лететь', 'космос', 'радость',
        'поезд', 'находить', 'гулять', 'горький', 'бочок', 'ночь', 'счастье',
        'уничтожение', 'дьявол', 'коробка', 'спасть', 'кожа', 'провинция',
        'прелесть', 'тюрьма', 'низкий', 'сверкать', 'темнеть', 'солнце',
        'дружно', 'настать', 'блин', 'степь', 'самостоятельно', 'крутой',
        'картинка', 'зачем', 'рабочий', 'необычный', 'армейский', 'труп',
        'ягода', 'около', 'монета', 'естественный', 'юный', 'район', 'скрытый',
        'поймать', 'строительство', 'палата', 'миг', 'триста', 'штаб', 'ломать',
        'возможно', 'полюбить', 'человечек', 'легко', 'чувство', 'ручей',
        'карман', 'деньги', 'неправда', 'сравнение', 'грудь', 'отъезд',
        'возникновение', 'степь', 'возбуждение', 'деловой', 'следовательно',
        'жидкий', 'сынок', 'художественный', 'поколение', 'расстегнуть', 'пища',
        'ученый', 'секунда', 'успокоиться', 'вряд', 'аж', 'вскакивать', 'мимо',
        'падать', 'потянуться', 'угроза', 'растеряться', 'бегать', 'стакан',
        'о', 'кпсс', 'ныне', 'пол', 'реклама', 'при', 'школьный', 'премьера',
        'дальний', 'потрясти', 'освобождение', 'покидать', 'наступать', 'жить',
        'какой', 'обида', 'командование', 'девка', 'выражаться', 'головной',
        'второй', 'князь', 'социалистический', 'головка', 'привлекать', 'через',
        'господь', 'результат', 'отметить', 'ведь', 'падаль', 'покидать',
        'художественный', 'правый', 'висеть', 'лапа', 'каюта', 'слишком',
        'нервно', 'серьезный', 'зима', 'заработать', 'эффект', 'пропасть',
        'плод', 'что', 'висеть', 'холодно', 'единый', 'выкинуть', 'мрачно',
        'выгнать', 'умирать', 'иной', 'космос', 'природа', 'функция',
        'поставить', 'оборот', 'услать', 'очередной', 'медицина', 'функция',
        'зарплата', 'выдержать', 'расстройство', 'адвокат', 'задержать',
        'появление', 'инвалид', 'интеллектуальный', 'исследование', 'господь',
        'смертельный', 'спичка', 'вариант', 'рай', 'одиннадцать', 'чем',
        'манера', 'магазин', 'поговорить', 'полоска', 'помимо', 'построить',
        'домашний', 'механический', 'сохранять', 'отражение', 'научить',
        'тесно', 'аллея', 'прежний', 'посидеть', 'славный', 'очутиться',
        'лететь', 'невозможно', 'порядок', 'выразить', 'спешить', 'сынок',
        'ребятишки', 'угроза', 'оставить', 'цвет', 'налево', 'парень',
        'миллиард', 'горький', 'трубка', 'подробность', 'пасть', 'непривычный',
        'угодный', 'засунуть', 'цель', 'запретить', 'дремать', 'разуметься',
        'приходить', 'совещание', 'постоянный', 'анализ', 'терапия', 'приятель',
        'процесс', 'академик', 'металл', 'развернуться', 'жестокий', 'интернет',
        'банда', 'изменение', 'коллектив', 'похороны', 'устройство',
        'торопливый', 'разводить', 'промолчать', 'подземный', 'пламя',
        'редактор', 'теория', 'карандаш', 'упор', 'означать', 'бабочка',
        'четыре', 'столетие', 'разнообразный', 'витрина', 'нож', 'команда',
        'шлем', 'недостаток', 'протягивать', 'за', 'металл', 'добиться',
        'сутки', 'четко', 'предоставить', 'тысяча', 'запеть', 'бригада',
        'мелочь', 'выраженный', 'пересечь', 'сходить', 'вообще', 'рис', 'банк',
        'бак', 'передо', 'назначить', 'важный', 'правление', 'палка', 'трясти',
        'уронить', 'витрина', 'основание', 'да', 'перебивать', 'дыхание',
        'применяться', 'июнь', 'бетонный', 'избегать', 'умолять', 'мягкий',
        'заявление', 'конференция', 'встать', 'свежий', 'сопровождаться',
        'цепочка', 'выражение', 'угол', 'ботинок', 'ложиться', 'инструкция',
        'присесть', 'решетка', 'еврейский', 'порог', 'зеленый', 'граница',
        'ставить', 'смелый', 'сустав', 'роса', 'демократия', 'вывести',
        'конструкция', 'задрать', 'багровый', 'военный', 'направо', 'житель',
        'товар', 'неправда', 'материя', 'командующий', 'кидать', 'заложить',
        'лиловый', 'слать', 'горький', 'пространство', 'провал', 'мусор',
        'наткнуться', 'торговля', 'монета', 'место', 'спалить', 'бровь',
        'левый', 'хлеб', 'коричневый', 'потом', 'страсть', 'виднеться',
        'роскошный', 'способ', 'костер', 'заведение', 'пропадать', 'слишком',
        'пятеро', 'мальчишка', 'тусклый', 'неожиданный', 'плясать', 'дурацкий',
        'дрогнуть', 'сбросить', 'прошептать', 'беспомощный', 'рота', 'песня',
        'тревога', 'некоторый', 'термин', 'нажать', 'видимо', 'валюта', 'набор',
        'боец', 'райком', 'новый', 'скользить', 'руководитель', 'волк',
        'изредка', 'понятный', 'пропаганда', 'остановить', 'исполнять', 'ход',
        'госпожа', 'печатать', 'командир', 'снимать', 'казнь', 'невыносимый',
        'спорт', 'тревога', 'уточнить', 'актриса', 'полностью', 'покинуть',
        'сверкающий', 'мотоцикл', 'дорогой', 'указанный', 'ремень', 'посвятить',
        'один', 'а', 'доставать', 'хозяйка', 'носок', 'написать', 'еврейский',
        'призыв', 'увеличиваться', 'равнодушный',
    )
